@@ -1,3 +1,3 @@
-fn main() {
+pub fn main() {
     println!("hello: Hello, world!");
 }
