@@ -4,7 +4,8 @@
 pub mod sample_module {
     //! `//!` comment can be used for the module.
 
-    /// `///` is a doc comment for the function, struct, or trait ...
+    /// `///` is a doc comment for the function, struct, or
+    /// trait ...
     pub fn public_fn_in_module(arg: i64) {
         // `//` comment is not a doc comment.
         println!(
@@ -25,7 +26,29 @@ pub fn public_function() {
 fn private_function() {
     println!("called `private_function()`",);
     println!(
-        "called `private_function()` `private_function()` `private_function`
-        `private_function()` `private_function()` `private_function()` `private_function()`"
+        "called `private_function()` `private_function()` `private_function` \
+         `private_function()` `private_function()` `private_function()` \
+         `private_function()`"
     );
 }
+
+pub mod another_mod;
+pub mod sub_mod;
+
+#[cfg(test)]
+mod tests {
+    #[test]
+    fn it_works() {
+        assert_eq!(2 + 2, 4);
+    }
+
+    #[test]
+    fn access_to_child_mod() {
+        super::another_mod::pub_in_crate();
+        // super means the parent of `tests` module.
+
+        // super::sub_mod::another_mod::pub_in_super();
+        // compile error because another_mod is only public in
+        // sub_mod;
+    }
+}
